@@ -5,7 +5,7 @@ use Mojo::File qw(path);
 use Mojo::JSON qw(decode_json);
 use Carp;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 has client_email => undef;
 has expires_in   => 3600;
@@ -74,6 +74,14 @@ sub from_json {
   return 1
 }
 
+sub as_form_data {
+  my ($self) = @_;
+  return {
+    grant_type => 'urn:ietf:params:oauth:grant-type:jwt-bearer',
+    assertion => $self->encode
+  }
+}
+
 1;
 
 
@@ -83,7 +91,7 @@ Mojo::JWT::Google - Service Account tokens
 
 =head1 VERSION
 
-0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -97,9 +105,7 @@ Mojo::JWT::Google - Service Account tokens
      scopes    => 'https://www.googleapis.com/auth/gmail.send',
      user_as   => 'some-email@your-org.com'); # if you have domain-wide delegation
   my $ua = Mojo::UserAgent->new;
-  my $tx = $ua->post('https://www.googleapis.com/oauth2/v4/token', form => {
-    grant_tpye => 'urn:ietf:params:oauth:grant-type:jwt-bearer'
-    assertion => $jwt->encode });
+  my $tx = $ua->post('https://www.googleapis.com/oauth2/v4/token', form => $gjwt->as_form_data);
   $tx->res->json('/access_token') # will contain your access token 
   
   # authenticating to use the Identity Aware Proxy
@@ -107,9 +113,7 @@ Mojo::JWT::Google - Service Account tokens
      from_json => '/my/secret/project-b98ale897.json',
      audience  => 'the-client-id-from-your-IAP');
   my $ua = Mojo::UserAgent->new;
-  my $tx = $ua->post('https://www.googleapis.com/oauth2/v4/token', form => {
-    grant_tpye => 'urn:ietf:params:oauth:grant-type:jwt-bearer'
-    assertion => $jwt->encode });
+  my $tx = $ua->post('https://www.googleapis.com/oauth2/v4/token', form => $gjwt->as_form_data);
   $tx->res->json('/id_token') # will contain your id token 
 
 =head1 DESCRIPTION
@@ -136,6 +140,12 @@ need to impersonate.
     ->new( from_json => '/my/secret.json',
            scopes    => [ '/my/scope/a', '/my/scope/b' ])->encode;
 
+
+To authenticate, send a post request to https://www.googleapis.com/oauth2/v4/token, 
+your Mojo::JWT::Google's as_form_data method.
+
+  $ua->post('https://www.googleapis.com/oauth2/v4/token', form => $gjwt->as_form_data);
+
 =cut
 
 =head1 ATTRIBUTES
